<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * A two column layout for the boost theme.
 *
 * @package   theme_boost
 * @copyright 2016 Damyon Wiese
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

global $DB, $PAGE;


$isfrontpage = false;

if ($PAGE->bodyid == 'page-site-index') {
    $isfrontpage = true;
}

user_preference_allow_ajax_update('drawer-open-nav', PARAM_ALPHA);
require_once($CFG->libdir . '/behat/lib.php');

$forgotpasswordurl = $CFG->wwwroot . '/login/forgot_password.php';
$loginurl = $CFG->wwwroot . '/login/index.php?authldap_skipntlmsso=1';
$logintoken = s(\core\session\manager::get_login_token());

if (isloggedin()) {
    $navdraweropen = (get_user_preferences('drawer-open-nav', 'true') == 'true');
    $loginvar = 1;
} else {
    $navdraweropen = false;
    $loginvar = 0;
}
$extraclasses = [];
if ($navdraweropen) {
    $extraclasses[] = 'drawer-open-left';
}
$bodyattributes = $OUTPUT->body_attributes($extraclasses);
$blockshtml = $OUTPUT->blocks('side-pre');
$hasblocks = strpos($blockshtml, 'data-block=') !== false;
$buildregionmainsettings = !$PAGE->include_region_main_settings_in_header_actions();
// If the settings menu will be included in the header then don't add it here.
$regionmainsettingsmenu = $buildregionmainsettings ? $OUTPUT->region_main_settings_menu() : false;

$coursegetstring = get_string('courses');
$coursedetail = '';

$course = $DB->get_records_sql('SELECT c.* FROM {course} c where id != ? AND visible = ? order by sortorder', array(1, 1));
$coursedetailsarray = array();

foreach ($course as $key => $coursevalue) {
    $coursedetailsarray[$key]["courseid"] = $CFG->wwwroot . "/course/view.php?id=" . $coursevalue->id;
    $coursedetailsarray[$key]["coursename"] = $coursevalue->fullname;
    $coursedetailsarray[$key]["visible"] = $coursevalue->visible;
    $coursecontext = context_course::instance($coursevalue->id);
    $isfile = $DB->get_records_sql(
        "Select * from {files} where contextid = ? and filename != ? and filearea = ?",
        array($coursecontext->id, ".", "overviewfiles")
    );
    if ($isfile) {
        foreach ($isfile as $key1 => $isfilevalue) {
            $courseimage = $CFG->wwwroot . "/pluginfile.php/" . $isfilevalue->contextid .
                "/" . $isfilevalue->component . "/" . $isfilevalue->filearea . "/" . $isfilevalue->filename;
        }
    }
    if (!empty($courseimage)) {
        $coursedetailsarray[$key]["courseimage"] = $courseimage;
    } else {
        $coursedetailsarray[$key]["courseimage"] = $CFG->wwwroot . "/theme/roshnilite/data/nopic.jpg";
    }
    $courseimage = '';

    $coursedetail .= '<div class="card" >';
    $coursedetail .= '<a class="text-dark" href="' . $coursedetailsarray[$key]["courseid"]  . '">';
    $coursedetail .= '<div class="watermark"><img class="card-img-top" src="' . $coursedetailsarray[$key]["courseimage"] . '"/></div>';
    $coursedetail .= '<div class="card-body px-1 py-3">
                            <h4 class="card-title">' . $coursedetailsarray[$key]["coursename"]  . '</h4>
                        </div>';
    $coursedetail .= '</a>';
    $coursedetail .= '</div>';

    if ($COURSE->id != 1) {
        $iscourse = true;
    } else {
        $iscourse = false;
    }
}


$templatecontext = [
    'sitename' => format_string($SITE->shortname, true, ['context' => context_course::instance(SITEID), "escape" => false]),
    'coursename' => format_string($COURSE->shortname, true, ['context' => context_course::instance(SITEID), "escape" => false]),
    'courseid' => format_string($COURSE->id, true, ['context' => context_course::instance(SITEID), "escape" => false]),
    'output' => $OUTPUT,
    'sidepreblocks' => $blockshtml,
    'hasblocks' => $hasblocks,
    'bodyattributes' => $bodyattributes,
    'navdraweropen' => $navdraweropen,
    'regionmainsettingsmenu' => $regionmainsettingsmenu,
    'hasregionmainsettingsmenu' => !empty($regionmainsettingsmenu),
    'coursedetail' => $coursedetail,
    'loginvar' => $loginvar,
    'loginurl' => $loginurl,
    'logintoken' => $logintoken,
    'forgotpasswordurl' => $forgotpasswordurl,
    'isfrontpage' => $isfrontpage,
    'iscourse' => $iscourse,
    'logosfooter' => $OUTPUT->image_url('logos_footer', 'theme'),
];

$nav = $PAGE->flatnav;
$templatecontext['flatnavigation'] = $nav;
$templatecontext['firstcollectionlabel'] = $nav->get_collectionlabel();

echo $OUTPUT->render_from_template('theme_para/columns2', $templatecontext);
